.. image:: https://img.shields.io/pypi/v/octomachinery.svg
   :target: https://pypi.org/project/octomachinery
   :alt: octomachinery @ PyPI

.. image:: https://img.shields.io/travis/com/sanitizers/octomachinery/master.svg?label=Linux%20builds%20%40%20Travis%20CI
   :target: https://travis-ci.com/sanitizers/octomachinery
   :alt: Travis CI build status

octomachinery
=============
Invisible engine driving octobot machines. Simple, yet powerful.

Web-site @ https://octomachinery.dev. Stay tuned!
